import { l as GetPermissionsRequest$1, G as GetPermissionsResponse$1, m as UpdatePermissionsRequest$1, U as UpdatePermissionsResponse$1, n as AddSpecialPermissionsRequest$1, a as AddSpecialPermissionsResponse$1, o as UpdateSpecialPermissionsRequest$1, c as UpdateSpecialPermissionsResponse$1, R as RemoveSpecialPermissionsRequest$1, p as RemoveSpecialPermissionsResponse$1, q as GetMyPermissionsRequest$1, d as GetMyPermissionsResponse$1 } from './data-v1-data-permissions-permissions.universal-B1qSIhq7.js';

/**
 * Permissions configuration of a data collection.
 *
 * Describes who can perform certain data operations on a collection.
 */
interface DataPermissions {
    /**
     * Data Collection ID that is subject of these permissions
     * @immutable
     * @maxLength 255
     */
    id?: string;
    /** Access level for data items read */
    itemRead?: AccessLevelWithLiterals;
    /** Access level for data items insert */
    itemInsert?: AccessLevelWithLiterals;
    /** Access level for data items update */
    itemUpdate?: AccessLevelWithLiterals;
    /** Access level for data items removal */
    itemRemove?: AccessLevelWithLiterals;
}
/**
 * Describes who can perform certain action.
 * Each level includes all levels below it (except UNDEFINED).
 */
declare enum AccessLevel {
    /** Not set */
    UNKNOWN = "UNKNOWN",
    /** Any subject, including visitors */
    ANYONE = "ANYONE",
    /** Any signed-in user (both site members and collaborators) */
    SITE_MEMBER = "SITE_MEMBER",
    /** Any signed-in user, but site members only have access to own items */
    SITE_MEMBER_AUTHOR = "SITE_MEMBER_AUTHOR",
    /** Site collaborator that has a role with CMS Access permission */
    CMS_EDITOR = "CMS_EDITOR",
    /** CMS administrators and users or roles granted with special access */
    PRIVILEGED = "PRIVILEGED"
}
/** @enumType */
type AccessLevelWithLiterals = AccessLevel | 'UNKNOWN' | 'ANYONE' | 'SITE_MEMBER' | 'SITE_MEMBER_AUTHOR' | 'CMS_EDITOR' | 'PRIVILEGED';
/** Special access granted to user or role */
interface SpecialPermissions extends SpecialPermissionsSubjectOneOf {
    /**
     * User ID that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    userId?: string;
    /**
     * Policy ID of (custom) role that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    policyId?: string;
    /**
     * ID of this special access, so it can be managed separately
     * @format GUID
     * @readonly
     */
    id?: string;
    /** If data item read is allowed */
    itemRead?: AccessWithLiterals;
    /** If data item insert is allowed */
    itemInsert?: AccessWithLiterals;
    /** If data item update is allowed */
    itemUpdate?: AccessWithLiterals;
    /** If data item remove is allowed */
    itemRemove?: AccessWithLiterals;
}
/** @oneof */
interface SpecialPermissionsSubjectOneOf {
    /**
     * User ID that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    userId?: string;
    /**
     * Policy ID of (custom) role that is subject of these permissions
     * @immutable
     * @maxLength 64
     */
    policyId?: string;
}
declare enum Access {
    /** Action is not specifically allowed, but can be allowed by top-level permissions */
    UNSPECIFIED = "UNSPECIFIED",
    /** Action is specifically allowed */
    ALLOWED = "ALLOWED"
}
/** @enumType */
type AccessWithLiterals = Access | 'UNSPECIFIED' | 'ALLOWED';
interface GetPermissionsRequest {
    /**
     * Data Collection ID to get permissions for
     * @maxLength 256
     */
    dataCollectionId: string;
}
interface GetPermissionsResponse {
    /** Requested data permissions */
    dataPermissions?: DataPermissions;
}
interface UpdatePermissionsRequest {
    /** Data permissions to update */
    dataPermissions: DataPermissions;
}
interface UpdatePermissionsResponse {
    /** Updated data permissions */
    dataPermissions?: DataPermissions;
}
interface AddSpecialPermissionsRequest {
    /**
     * Data Collection ID to add special permission for
     * @maxLength 256
     */
    dataCollectionId: string;
    /** Special permissions to add */
    specialPermissions: SpecialPermissions;
}
interface AddSpecialPermissionsResponse {
    /** Added special data permissions */
    specialPermissions?: SpecialPermissions;
}
interface UpdateSpecialPermissionsRequest {
    /** Special permissions to update */
    specialPermissions: SpecialPermissions;
}
interface UpdateSpecialPermissionsResponse {
    /** Updated special data permissions */
    specialPermissions?: SpecialPermissions;
}
interface RemoveSpecialPermissionsRequest {
    /**
     * Special permissions ID to remove
     * @format GUID
     */
    specialPermissionsId: string;
}
interface RemoveSpecialPermissionsResponse {
}
interface GetMyPermissionsRequest {
    /**
     * Data Collection ID to get permission for
     * @maxLength 256
     */
    dataCollectionId: string;
}
interface GetMyPermissionsResponse {
    /** If data item read is allowed */
    itemRead?: boolean;
    /** If data item insert is allowed */
    itemInsert?: boolean;
    /** If data item update is allowed */
    itemUpdate?: boolean;
    /** If data item remove is allowed */
    itemRemove?: boolean;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getPermissions(): __PublicMethodMetaInfo<'GET', {}, GetPermissionsRequest$1, GetPermissionsRequest, GetPermissionsResponse$1, GetPermissionsResponse>;
declare function updatePermissions(): __PublicMethodMetaInfo<'POST', {}, UpdatePermissionsRequest$1, UpdatePermissionsRequest, UpdatePermissionsResponse$1, UpdatePermissionsResponse>;
declare function addSpecialPermissions(): __PublicMethodMetaInfo<'POST', {}, AddSpecialPermissionsRequest$1, AddSpecialPermissionsRequest, AddSpecialPermissionsResponse$1, AddSpecialPermissionsResponse>;
declare function updateSpecialPermissions(): __PublicMethodMetaInfo<'POST', {
    specialPermissionsId: string;
}, UpdateSpecialPermissionsRequest$1, UpdateSpecialPermissionsRequest, UpdateSpecialPermissionsResponse$1, UpdateSpecialPermissionsResponse>;
declare function removeSpecialPermissions(): __PublicMethodMetaInfo<'DELETE', {
    specialPermissionsId: string;
}, RemoveSpecialPermissionsRequest$1, RemoveSpecialPermissionsRequest, RemoveSpecialPermissionsResponse$1, RemoveSpecialPermissionsResponse>;
declare function getMyPermissions(): __PublicMethodMetaInfo<'GET', {}, GetMyPermissionsRequest$1, GetMyPermissionsRequest, GetMyPermissionsResponse$1, GetMyPermissionsResponse>;

export { type __PublicMethodMetaInfo, addSpecialPermissions, getMyPermissions, getPermissions, removeSpecialPermissions, updatePermissions, updateSpecialPermissions };
