import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { G as GetPermissionsResponse, D as DataPermissions, U as UpdatePermissionsResponse, A as AddSpecialPermissionsOptions, a as AddSpecialPermissionsResponse, b as UpdateSpecialPermissions, c as UpdateSpecialPermissionsResponse, d as GetMyPermissionsResponse } from './data-v1-data-permissions-permissions.universal-B1qSIhq7.mjs';
export { f as Access, e as AccessLevel, ad as ActionEvent, n as AddSpecialPermissionsRequest, T as Condition, V as ConditionOperator, W as ConditionOperatorOperatorsOneOf, C as ConditionType, F as ConditionTypeOfOneOf, Y as ConditionValue, Z as ConditionValueValueOneOf, a0 as DependOnOperator, a7 as DomainEvent, a8 as DomainEventBodyOneOf, E as Effect, a3 as Empty, a9 as EntityCreatedEvent, ac as EntityDeletedEvent, ab as EntityUpdatedEvent, N as EnvironmentCondition, O as EnvironmentConditionConditionOneOf, X as EqualOperator, Q as ExperimentCondition, $ as ExperimentOperator, q as GetMyPermissionsRequest, l as GetPermissionsRequest, L as JoinedCondition, J as JoinedConditionOperator, _ as LikeOperator, M as MigrateCustomRolesRequest, r as MigrateCustomRolesResponse, u as PolicyAssigned, x as PolicyAssignment, a2 as PolicyAssignmentUpdated, s as PolicyAssignmentsUpdated, t as PolicyAssignmentsUpdatedEventOneOf, a4 as PolicyAuthorizationDataUpdated, B as PolicyCondition, a6 as PolicyOwner, i as PolicyOwnerType, a5 as PolicyStatement, P as PolicyType, a1 as PolicyUnassigned, R as RemoveSpecialPermissionsRequest, p as RemoveSpecialPermissionsResponse, z as Resource, y as ResourcePath, aa as RestoreInfo, H as SimpleCondition, h as SimpleConditionOperator, I as SimpleConditionValue, K as SimpleConditionValueValueOneOf, j as SpecialPermissions, k as SpecialPermissionsSubjectOneOf, v as Subject, w as SubjectContext, g as SubjectContextType, S as SubjectType, m as UpdatePermissionsRequest, o as UpdateSpecialPermissionsRequest } from './data-v1-data-permissions-permissions.universal-B1qSIhq7.mjs';

declare function getPermissions$1(httpClient: HttpClient): GetPermissionsSignature;
interface GetPermissionsSignature {
    /**
     * Returns data permissions for a data collection
     * @param - Data Collection ID to get permissions for
     */
    (dataCollectionId: string): Promise<GetPermissionsResponse>;
}
declare function updatePermissions$1(httpClient: HttpClient): UpdatePermissionsSignature;
interface UpdatePermissionsSignature {
    /**
     * Updates data permissions for a data collection
     *
     * NOTE that special permissions are not updated using this API, use dedicated methods for it.
     * @param - Data permissions to update
     */
    (dataPermissions: DataPermissions): Promise<UpdatePermissionsResponse>;
}
declare function addSpecialPermissions$1(httpClient: HttpClient): AddSpecialPermissionsSignature;
interface AddSpecialPermissionsSignature {
    /**
     * Adds special data permissions for particular user/group
     * Errors:
     * - `ALREADY_EXISTS` in case if special permission for same subject already exists
     * @param - Data Collection ID to add special permission for
     */
    (dataCollectionId: string, options: AddSpecialPermissionsOptions): Promise<AddSpecialPermissionsResponse>;
}
declare function updateSpecialPermissions$1(httpClient: HttpClient): UpdateSpecialPermissionsSignature;
interface UpdateSpecialPermissionsSignature {
    /**
     * Updates special data permissions for particular user/group.
     * Any omitted permissions will be set to UNSPECIFIED.
     * @param - ID of this special access, so it can be managed separately
     */
    (_id: string, specialPermissions: UpdateSpecialPermissions): Promise<UpdateSpecialPermissionsResponse>;
}
declare function removeSpecialPermissions$1(httpClient: HttpClient): RemoveSpecialPermissionsSignature;
interface RemoveSpecialPermissionsSignature {
    /**
     * Deletes special data permissions for particular user/group
     * @param - Special permissions ID to remove
     */
    (specialPermissionsId: string): Promise<void>;
}
declare function getMyPermissions$1(httpClient: HttpClient): GetMyPermissionsSignature;
interface GetMyPermissionsSignature {
    /**
     * Returns current user permissions for given data collection
     * @param - Data Collection ID to get permission for
     */
    (dataCollectionId: string): Promise<GetMyPermissionsResponse>;
}

declare const getPermissions: MaybeContext<BuildRESTFunction<typeof getPermissions$1> & typeof getPermissions$1>;
declare const updatePermissions: MaybeContext<BuildRESTFunction<typeof updatePermissions$1> & typeof updatePermissions$1>;
declare const addSpecialPermissions: MaybeContext<BuildRESTFunction<typeof addSpecialPermissions$1> & typeof addSpecialPermissions$1>;
declare const updateSpecialPermissions: MaybeContext<BuildRESTFunction<typeof updateSpecialPermissions$1> & typeof updateSpecialPermissions$1>;
declare const removeSpecialPermissions: MaybeContext<BuildRESTFunction<typeof removeSpecialPermissions$1> & typeof removeSpecialPermissions$1>;
declare const getMyPermissions: MaybeContext<BuildRESTFunction<typeof getMyPermissions$1> & typeof getMyPermissions$1>;

export { AddSpecialPermissionsOptions, AddSpecialPermissionsResponse, DataPermissions, GetMyPermissionsResponse, GetPermissionsResponse, UpdatePermissionsResponse, UpdateSpecialPermissions, UpdateSpecialPermissionsResponse, addSpecialPermissions, getMyPermissions, getPermissions, removeSpecialPermissions, updatePermissions, updateSpecialPermissions };
